@@ -1,4 +1,4 @@
-import improviser.Ensembles.Bands as Bands
+import Bands
 from improviser.Progressions import *
 
 class Block:
