@@ -4,6 +4,7 @@ from Blocks import Block
 from os import sys
 from optparse import OptionParser
 from mingus.core import notes
+import Bands
 
 try:
 	from mingus.extra import fluidsynth
@@ -12,6 +13,10 @@ except:
 	print "A download is available at http://mingus.googlecode.com/"
 	sys.exit(1)
 
+def get_available_bands():
+	return [x for x in Bands.__dict__ if \
+		type(getattr(Bands, x)) == type([])]
+
 if __name__ == '__main__':
 
 	parser = OptionParser()
@@ -19,12 +24,19 @@ if __name__ == '__main__':
 		help="Set the bpm to start with.")
 	parser.add_option("-d", "--duration", dest="duration", type="int",
 		help="Set the number of times the progression should be repeated.")
+	parser.add_option("-e", "--ensemble", dest="ensemble", 
+		metavar="EN", help="Set the ensemble")
 	parser.add_option("-f", "--frontend", dest="frontend", 
-		metavar="F", help="Choose front-end [blocks, lines]")
+		metavar="F", help="Choose front-end [blocks, lines, mixed]")
+	parser.add_option("-l", "--list", action="store_true", 
+		dest="list_bands", default=False, 
+		help="List available ensembles. Don't play.")
 	parser.add_option("-k", "--key", dest="key",
 		help="Set the key to start in.")
 	parser.add_option("-q", "--quiet", action="store_false",
 		dest="verbose")
+	parser.add_option("-s", "--swing", action="store_true",
+		dest="swing", default=False, help="Set swing")
 	parser.add_option("-v", "--verbose", action="store_true", 
 		dest="verbose", default=True)
 	parser.add_option("-w", "--wildness", type="float", dest="wild",
@@ -35,6 +47,7 @@ if __name__ == '__main__':
 
 	visual = None
 	block = Block()
+	block.swing = options.swing
 
 	if options.frontend == "blocks":
 		from Visualizations import PygameBlockVisualization
@@ -46,6 +59,22 @@ if __name__ == '__main__':
 		from Visualizations import PygameMixedVisualizations
 		visual = PygameMixedVisualizations(400,400)
 
+	if options.list_bands:
+		i = 1
+		for x in get_available_bands():
+			print "%d. %s" % (i, x)
+			i += 1
+		sys.exit(0)
+
+	if options.ensemble != None:
+		if options.ensemble in get_available_bands():
+			block.instruments = getattr(Bands, options.ensemble)
+		else:
+			if options.verbose:
+				print "Unknown ensemble:", options.ensemble
+
+
+
 	if options.key != None:
 		if notes.is_valid_note(options.key):
 			block.key = options.key
