@@ -10,7 +10,6 @@ class Sequencer:
 	progression = []
 	state = {}
 	iterations = 0
-	play_iterations = 1000
 	paint_function = None
 	refresh_function = None
 	update_function = None
@@ -18,6 +17,7 @@ class Sequencer:
 
 	def __init__(self, block):
 		self.block = block
+		self.play_iterations = block.get_duration()
 		self.iteration()
 
 	def block_iteration(self):
